@@ -163,7 +163,7 @@ def validateSingleURI(service, URI, uriName='', expectedType=None, expectedJson=
                 if not redfish_obj.HasValidUriStrict and redfish_obj.payload.get('Id') is not None:
                     counts['failRedfishUriStrict'] += 1
                     messages['@odata.id'].result = 'FAIL'
-                    my_logger.error('URI {} does not match object ID of resource'.format(odata_id, redfish_obj.Type))
+                    my_logger.error('The Id property does not match the last segment of the URI {}'.format(odata_id))
             else:
                 if '/Oem/' in odata_id:
                     counts['warnRedfishUri'] += 1
@@ -302,11 +302,7 @@ def validateURITree(service, URI, uriName, expectedType=None, expectedJson=None,
 
     refLinks = []
 
-    if inAnnotation and service.config['uricheck']:
-        service.catalog.flags['ignore_uri_checks'] = True
     validateSuccess, counts, results, links, thisobj = validateSingleURI(service, URI, uriName, expectedType, expectedJson, parent)
-    if inAnnotation and service.config['uricheck']:
-        service.catalog.flags['ignore_uri_checks'] = False
 
     # If successful and a MessageRegistryFile...
     if validateSuccess and 'MessageRegistryFile.MessageRegistryFile' in thisobj.Type.getTypeTree():
